@@ -34,7 +34,7 @@ class Confluence(AtlassianRestAPI):
         :param page_id: A string containing the id of the type content container.
         :param type:
         :param start: OPTIONAL: The start point of the collection to return. Default: None (0).
-        :param limit: OPTIONAL: how many items should be returned after the start index. Default: Site limit.
+        :param limit: OPTIONAL: how many items should be returned after the start index. Default: Site limit 200.
         :return:
         """
         params = {}
@@ -46,7 +46,7 @@ class Confluence(AtlassianRestAPI):
         url = 'rest/api/content/{page_id}/child/{type}'.format(page_id=page_id, type=type)
         log.info(url)
         try:
-            return self.get(url)
+            return (self.get(url, params=params) or {}).get('results')
         except IndexError as e:
             log.error(e)
             return None
@@ -66,7 +66,7 @@ class Confluence(AtlassianRestAPI):
         :param page_id: content ID
         :return:
         """
-        return self.get_page_by_id(page_id, expand='space')['space']['key']
+        return ((self.get_page_by_id(page_id, expand='space') or {}).get('space') or {}).get('key')
 
     def get_page_by_title(self, space, title, start=None, limit=None):
         """
@@ -91,7 +91,7 @@ class Confluence(AtlassianRestAPI):
             params['title'] = str(title)
         url = 'rest/api/content'
         try:
-            return self.get(url, params=params).get('results')[0]
+            return (self.get(url, params=params) or {}).get('results')[0]
         except IndexError as e:
             log.error(e)
             return None
@@ -159,7 +159,7 @@ class Confluence(AtlassianRestAPI):
         url = 'rest/api/content?spaceKey={space}&limit={limit}&start={start}'.format(space=space,
                                                                                      limit=limit,
                                                                                      start=start)
-        return self.get(url)['results']
+        return (self.get(url) or {}).get('results')
 
     def get_all_pages_from_space_trash(self, space, start=0, limit=500, status='trashed'):
         """
@@ -194,6 +194,24 @@ class Confluence(AtlassianRestAPI):
                                                                                                      status=status)
         return (self.get(url) or {}).get('results')
 
+    def get_all_draft_pages_from_space_through_cql(self, space, start=0, limit=500, status='draft'):
+        """
+        Search list of draft pages by space key
+        Use case is cleanup old drafts from Confluence
+        :param space: Space Key
+        :param status: Can be changed
+        :param start: OPTIONAL: The start point of the collection to return. Default: None (0).
+        :param limit: OPTIONAL: The limit of the number of pages to return, this may be restricted by
+                            fixed system limits. Default: 500
+        :return:
+        """
+        url = 'rest/api/content?cql=space=spaceKey={space} and status={status}'.format(space=space,
+                                                                                       status=status)
+        params = {}
+        params['limit'] = limit
+        params['start'] = start
+        return (self.get(url, params=params) or {}).get('results')
+
     def get_all_restictions_for_content(self, content_id):
         """
         Returns info about all restrictions by operation.
@@ -209,16 +227,28 @@ class Confluence(AtlassianRestAPI):
         :param page_id:
         :return:
         """
-        url = 'rest/api/content/{page_id}?status=trashed'.format(page_id=page_id)
-        return self.delete(url)
+        return self.remove_page(page_id=page_id, status='trashed')
 
-    def remove_page(self, page_id):
+    def remove_page_as_draft(self, page_id):
         """
-        This method removed page
+        This method removed page from trash
         :param page_id:
         :return:
         """
-        url = 'rest/api/content/{page_id}'.format(page_id=page_id)
+        return self.remove_page(page_id=page_id, status='draft')
+
+    def remove_page(self, page_id, status=None):
+        """
+        This method removed page
+        :param page_id:
+        :param status: OPTIONAL: type of page
+        :return:
+        """
+        if status is None:
+            url = 'rest/api/content/{page_id}'.format(page_id=page_id)
+        else:
+            url = 'rest/api/content/{page_id}?status={status}'.format(page_id=page_id, status=status)
+
         return self.delete(url)
 
     def create_page(self, space, title, body, parent_id=None, type='page'):
@@ -430,7 +460,7 @@ class Confluence(AtlassianRestAPI):
         :return: get properties
         """
         url = 'rest/api/content/{page_id}?expand=ancestors'.format(page_id=page_id)
-        return self.get(path=url).get('ancestors')
+        return (self.get(path=url) or {}).get('ancestors')
 
     def clean_all_caches(self):
         """ Clean all caches from cache management"""
